#!/bin/bash
 
Custom_Key="custom_key"
Authorized="/home/secuser/.ssh/authorized_keys"
 
# check private key
openssl rsa -in /home/secuser/$Custom_Key -check
private=`echo $?`
 
if [ $private == 0 ] ;
then
   if [ -f /home/secuser/$Custom_Key.pub ] ;
   then
      # copy pub & priv keys
      mv /home/secuser/$Custom_Key* /home/secuser/.ssh/.
      chmod 600 /home/secuser/.ssh/$Custom_Key*
      chown secuser /home/secuser/.ssh/$Custom_Key*
      # remove old custom_key.pub in /home/secuser/.ssh/authorized_keys
      sed -i '/custom_key.pub/d' $Authorized
      # add new pub key in /home/secuser/.ssh/authorized_keys
      echo "">> $Authorized
      awk '{print $1 " " $2 " custom_key.pub" }' /home/secuser/.ssh/$Custom_Key.pub >> $Authorized
      # delete pub key
      rm /home/secuser/.ssh/$Custom_Key.pub
      exit 0
   else
      echo "Missing public key"
      exit 1
   fi
else
   echo "Missing or Bad private key"
   exit 1
fi
